@@ -4,16 +4,14 @@ Main interface for forecastquery service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_forecastquery import (
         Client,
         ForecastQueryServiceClient,
     )
 
-    session = boto3.Session()
-
-    client: ForecastQueryServiceClient = boto3.client("forecastquery")
-    session_client: ForecastQueryServiceClient = session.client("forecastquery")
+    session = Session()
+    client: ForecastQueryServiceClient = session.client("forecastquery")
     ```
 """
 from .client import ForecastQueryServiceClient
