@@ -24,8 +24,10 @@ __all__ = (
     "DataPointTypeDef",
     "QueryForecastRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
+    "QueryWhatIfForecastRequestRequestTypeDef",
     "ForecastTypeDef",
     "QueryForecastResponseTypeDef",
+    "QueryWhatIfForecastResponseTypeDef",
 )
 
 DataPointTypeDef = TypedDict(
@@ -72,6 +74,31 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+_RequiredQueryWhatIfForecastRequestRequestTypeDef = TypedDict(
+    "_RequiredQueryWhatIfForecastRequestRequestTypeDef",
+    {
+        "WhatIfForecastArn": str,
+        "Filters": Mapping[str, str],
+    },
+)
+_OptionalQueryWhatIfForecastRequestRequestTypeDef = TypedDict(
+    "_OptionalQueryWhatIfForecastRequestRequestTypeDef",
+    {
+        "StartDate": str,
+        "EndDate": str,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class QueryWhatIfForecastRequestRequestTypeDef(
+    _RequiredQueryWhatIfForecastRequestRequestTypeDef,
+    _OptionalQueryWhatIfForecastRequestRequestTypeDef,
+):
+    pass
+
+
 ForecastTypeDef = TypedDict(
     "ForecastTypeDef",
     {
@@ -87,3 +114,11 @@ QueryForecastResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+QueryWhatIfForecastResponseTypeDef = TypedDict(
+    "QueryWhatIfForecastResponseTypeDef",
+    {
+        "Forecast": ForecastTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
